nommy
=====

A python byte and bit parser inspired by Rust's nom.

Installation
------------

From the project root directory::

    $ python setup.py install

Usage
-----

Simply run it::

    $ nommy

Use --help/-h to view info on the arguments::

    $ nommy --help

Release Notes
-------------

:0.0.1:
    Project created
